@@ -105,13 +105,13 @@ namespace Banter
 			Gtk.Application.Init ();
 			program = 
 				new Gnome.Program (
-						"novell-rtc-application",
+						"banter",
 						Defines.Version,
 						Gnome.Modules.UI,
 						args);
 
 			// Call Init before anything so the people objects are in place
-			PersonStore.Instance.Init();
+			PersonManager.Instance.Init();
 			
 			// Create and start up the Person Sync
 			personSync = new PersonSync();
