@@ -72,7 +72,7 @@ namespace Banter
 			//lastSender = null;
 			shiftKeyPressed = false;
 
-			Person peer = PersonStore.GetPersonByJabberId (conv.PeerUser.Uri);
+			Person peer = PersonManager.GetPersonByJabberId (conv.PeerUser.Uri);
 			chatWindows[peer.Id] = this;
 			
 			// Update the window title
@@ -81,13 +81,14 @@ namespace Banter
 			
 			this.DefaultSize = new Gdk.Size (400, 800); 
 			
-			SetUpWidgets ();
+			SetUpWidgets (peer);
 			Realized += WindowRealized;
 			DeleteEvent += WindowDeleted;
+			
 		}
 		
 #region Private Methods
-		void SetUpWidgets ()
+		void SetUpWidgets (Person peer)
 		{
 			hpaned = new HPaned ();
 			hpaned.CanFocus = true;
@@ -110,10 +111,11 @@ namespace Banter
 			personControlVBox.Show ();
 			rightPaneVBox.PackStart (personControlVBox, false, false, 0);
 			
-			Label label = new Label (Catalog.GetString ("Person Widget Placeholder"));
-			label.Xalign = 0;
-			label.Show ();
-			personControlVBox.PackStart (label, false, false, 0);
+			PersonCard card = new PersonCard(peer);
+			card.Size = PersonCardSize.Medium;
+			// Not sure why but we need to call ShowAll on the PersonCard for it to display
+			card.ShowAll();
+			personControlVBox.PackStart (card, true, true, 0);
 			
 			HBox hbox = new HBox (false, 0);
 			hbox.Show ();
@@ -214,15 +216,14 @@ Logger.Debug ("OnMessageReceived called: {0}", message.Text);
 		void OnTapiocaMessageReceived (Conversation conversation, Message message)
 		{
 			string avatarPath = null;
-Logger.Debug ("OnMessageReceived called: {0}", message.Text);
-			
-			Logger.Debug ("Peer Handle: {0}", conversation.PeerUser.Contact.Handle.Id);
+			Logger.Debug ("OnMessageReceived called: {0}", message.Text);
+			Logger.Debug ("Peer Handle: {0}", conversation.PeerUser.ID);
 			Logger.Debug ("Peer Screenname: {0}", conversation.PeerUser.Uri);
 			Logger.Debug ("Sender: {0}", conversation.PeerUser.Alias);
 			
 			Person person = null;
 			try {
-				person = PersonStore.GetPerson (conversation.PeerUser);
+				person = PersonManager.GetPerson (conversation.PeerUser);
 			} catch{}
 			
 			if(person != null)
@@ -238,32 +239,14 @@ Logger.Debug ("OnMessageReceived called: {0}", message.Text);
 			string avatarPath = null;
 Logger.Debug ("OnMessageSent called: {0}", message.Text);
 
-			Person person = PersonStore.GetPersonByJabberId(conversation.MeContact.Uri);
+			/*
+			Person person = PersonManager.GetPersonByJabberId(conversation.MeContact.Uri);
 			if(person != null)
 				avatarPath = person.GetScaledAvatar(36);
+			*/
 			AddMessage (message, false, conversation.CurrentMessageSameAsLast, avatarPath);
 		}
 		
-		/*
-		void OnMessageSent (Conversation conversation, Message message)
-		{
-Logger.Debug ("OnMessageSent called: {0}", message.Text);
-			// FIXME: This should eventually pull the from off of the Message
-			Person sender = null;
-			try {
-				sender = app.GetPerson (conversation.Me);
-			} catch (Exception e) {
-				Console.WriteLine ("Application.GetPerson () threw an exception: {0}\n{1}", e.Message, e.StackTrace);
-			}
-			
-			bool contentIsSimilar =
-				(lastSender == null || lastSender != sender || message is TextMessage == false) ?
-					false : true;
-			AddMessage (message, false, contentIsSimilar);
-			lastSender = sender;
-		}
-		*/
-		
 		void AddMessage (Message message, bool incoming, bool contentIsSimilar, string avatarPath)
 		{
 			messagesView.AddMessage (message, incoming, contentIsSimilar, avatarPath);
@@ -286,7 +269,8 @@ Logger.Debug ("OnMessageSent called: {0}", message.Text);
 				break;
 			case Gdk.Key.Return:
 				if (!shiftKeyPressed) {
-					SendMessage ();
+					if(!HandleMessageTrigger())
+						SendMessage ();
 					// Prevent the event from passing on to the TextView
 					retVal = true;
 				}
@@ -323,23 +307,51 @@ Logger.Debug ("OnMessageSent called: {0}", message.Text);
 			}
 		}
 		
+		private bool HandleMessageTrigger()
+		{
+			bool handled = false;
+			
+			string text = typingTextView.Buffer.Text;
+			if(text.StartsWith("/status ")) {
+				string statusText = text.Substring(8);
+				if(statusText.Length > 0) {
+					if(PersonManager.Me != null) {
+						Presence presence = new Presence(PersonManager.Me.Presence.Type);
+						presence.Message = statusText;
+						PersonManager.Me.SetStatus(presence);
+					}
+				}
+				typingTextView.Buffer.Clear ();
+				handled = true;
+			}
+			
+			return handled;
+		}
+		
 		private void SendMessage ()
 		{
+			/*
 			if (conv == null) {
 				Logger.Info ("This window does not have a valid Conversation and cannot be used to chat with yet.");
 				return;
 			}
+			*/
 			
 			// Grab the text from the TextBuffer and clear it out
 			string text = typingTextView.Buffer.Text;
 			typingTextView.Buffer.Clear ();
 			
 			TextMessage msg = new TextMessage (text);
-			conv.SendTapiocaMessage (msg);
+			conv.SendMessage (msg);
 		}
 		
 		private void WindowRealized (object sender, EventArgs args)
 		{
+			// Check for any existing messages
+			Message[] messages = conv.GetReceivedMessages();
+			foreach (Message msg in messages)
+				OnTapiocaMessageReceived (conv, msg);
+				
 			// Set the default focus to the TextView where users should type
 			typingTextView.GrabFocus ();
 		}
