@@ -72,7 +72,7 @@ namespace Banter
 		private Widget sidebar;
 		private Image avatarImage;
 		private Label myDisplayName;
-		private ComboBoxEntry statusComboBoxEntry;
+		private StatusEntry statusEntry;
 		
 		private Entry searchEntry;
 		private Button cancelSearchButton;
@@ -351,7 +351,7 @@ namespace Banter
 			
 			Move (xPos, yPos);
 
-			groupTreeModel = PersonStore.Groups;
+			groupTreeModel = PersonManager.Groups;
 			groupButtonMap = new Dictionary<int, GroupButton> ();
 			
 			saveStateTimeout = new InterruptableTimeout ();
@@ -424,8 +424,8 @@ namespace Banter
 		{
 			HBox hbox = new HBox (false, 4);
 			
-			if( (PersonStore.Me != null) && (PersonStore.Me.Photo != null) )
-				avatarImage = new Image(PersonStore.Me.Photo.ScaleSimple(48,48,Gdk.InterpType.Bilinear));
+			if( (PersonManager.Me != null) && (PersonManager.Me.Photo != null) )
+				avatarImage = new Image(PersonManager.Me.Photo.ScaleSimple(48,48,Gdk.InterpType.Bilinear));
 			else
 				avatarImage = new Image (Utilities.GetIcon ("blank-photo-128", 32));
 
@@ -443,34 +443,50 @@ namespace Banter
 			myDisplayName.Show ();
 			vbox.PackStart (myDisplayName, true, true, 0);
 			
-			statusComboBoxEntry = ComboBoxEntry.NewText ();
-			statusComboBoxEntry.KeyPressEvent += OnStatusComboKeyPress;
-			statusComboBoxEntry.Changed += OnStatusComboChanged;
+			statusEntry = new StatusEntry ();
+			statusEntry.PresenceChanged += OnStatusEntryChanged;
+			statusEntry.Show ();
+			vbox.PackStart (statusEntry, false, false, 0);
 			
-			statusComboBoxEntry.Show ();
-			vbox.PackStart (statusComboBoxEntry, false, false, 0);
+//			statusComboBoxEntry = ComboBoxEntry.NewText ();
+//			statusComboBoxEntry.KeyPressEvent += OnStatusComboKeyPress;
+//			statusComboBoxEntry.Changed += OnStatusComboChanged;
+			
+//			statusComboBoxEntry.Show ();
+//			vbox.PackStart (statusComboBoxEntry, false, false, 0);
 			
 			hbox.Show ();
 			return hbox;
 		}
 		
-		private void OnStatusComboKeyPress (object sender, KeyPressEventArgs args)
+		private void OnStatusEntryChanged (Presence presence)
+		{
+			Logger.Debug ("Setting precense on Me to {0}", presence.Message);
+			
+			if (PersonManager.Me != null) {
+				PersonManager.Me.SetStatus (presence);
+				
+				Logger.Debug ("FIXME: Save off a custom presence message so when Banter restarts, they'll be available.");
+			}
+		}
+
+/*		private void OnStatusComboKeyPress (object sender, KeyPressEventArgs args)
 		{
 			if (args.Event.Key == Gdk.Key.Return) {
-				if (PersonStore.Me != null) {
+				if (PersonManager.Me != null) {
 					Logger.Debug ("FIXME: Set \"my\" status to: {0}",
 							statusComboBoxEntry.ActiveText);
-					PersonStore.Me.Presence.Message =
+					PersonManager.Me.Presence.Message =
 							statusComboBoxEntry.ActiveText;
 				}
 			}
 		}
-		
-		private void OnStatusComboChanged (object sender, EventArgs args)
+*/		
+/*		private void OnStatusComboChanged (object sender, EventArgs args)
 		{
 			Logger.Debug ("OnStatusComboChanged");
 		}
-		
+*/		
 		private Widget CreateSidebarSearchEntry ()
 		{
 			VBox vbox = new VBox (false, 0);
@@ -682,7 +698,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			Logger.Debug ("Adding group button: {0}", button.PersonGroup.DisplayName);
 			button.Show ();
 			button.Clicked += OnGroupButtonClicked;
-			button.DeleteClicked += OnGroupButtonDeleteClicked;
+			button.RightClicked += OnGroupButtonRightClicked;
 			groupButtonsVBox.PackStart (button, false, false, 0);
 			groupButtonMap [path.Indices [0]] = button;
 		}
@@ -711,8 +727,8 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		#region method overrides
 		protected override bool OnDeleteEvent (Gdk.Event evnt)
 		{
-			if (PersonStore.Me != null)
-				PersonStore.Me.PresenceUpdated -= OnMyPresenceUpdated;
+			if (PersonManager.Me != null)
+				PersonManager.Me.PresenceUpdated -= OnMyPresenceUpdated;
 			
 			groupTreeModel.RowInserted -= OnGroupRowInserted;
 			groupTreeModel.RowDeleted -= OnGroupRowDeleted;
@@ -731,7 +747,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		private void OnRealizeWidget (object sender, EventArgs args)
 		{
 			// Set "my" display name
-			Person me = PersonStore.Me;
+			Person me = PersonManager.Me;
 			if (me != null) {
 				myDisplayName.Markup =
 					string.Format (
@@ -739,7 +755,9 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 						me.DisplayName);
 				
 				// Set "my" status
-				statusComboBoxEntry.AppendText (me.Presence.Message);
+				statusEntry.Presence = me.Presence;
+				
+				Logger.Debug ("FIXME: Populate the StatusEntry widget with saved status messages.");
 				
 				me.PresenceUpdated += OnMyPresenceUpdated;
 			}
@@ -761,7 +779,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			// Set the view to the proper group
 
 			if (string.Compare (initialGroupId, "0") == 0) {
-				OnEveryoneClicked (this, EventArgs.Empty);
+				SelectEveryoneGroup();
 			} else {
 				foreach (GroupButton groupButton in groupButtonMap.Values) {
 					PersonGroup group = groupButton.PersonGroup;
@@ -801,15 +819,20 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		private void OnEveryoneClicked (object sender, EventArgs args)
 		{
 			if (selectedGroup != null) { // Everyone isn't already selected
-				Title = Catalog.GetString ("Everyone - Banter");
-				selectedGroup = null;
-				
-				personView.Model = PersonStore.People;
-				
-				QueueSaveState ();
+				SelectEveryoneGroup();
 			}
 		}
 		
+		private void SelectEveryoneGroup()
+		{
+			Title = Catalog.GetString ("Everyone - Banter");
+			selectedGroup = null;
+			
+			personView.Model = PersonManager.People;
+			
+			QueueSaveState ();
+		}
+		
 		private void OnNewGroupClicked (object sender, EventArgs args)
 		{
 			HIGMessageDialog dialog =
@@ -829,7 +852,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 				if (groupName.Length > 0) {
 					try {
 						PersonGroup group = new PersonGroup (groupName);
-						PersonStore.AddGroup (group);
+						PersonManager.AddGroup (group);
 					} catch (Exception e) {
 						Logger.Debug ("Couldn't create a group: {0}\n{1}\n{2}",
 								groupName, e.Message, e.StackTrace);
@@ -902,7 +925,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		
 		private void OnMyPresenceUpdated (Person me)
 		{
-			statusComboBoxEntry.AppendText (me.Presence.Message);
+			statusEntry.Presence = me.Presence;
 		}
 		
 		private void OnGroupRowInserted (object sender, RowInsertedArgs args)
@@ -979,7 +1002,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			QueueSaveState ();
 		}
 		
-		private void OnGroupButtonDeleteClicked (GroupButton sender, PersonGroup group)
+		private void OnGroupButtonRightClicked (GroupButton sender, PersonGroup group)
 		{
 			HIGMessageDialog dialog = new HIGMessageDialog (
 				this, DialogFlags.DestroyWithParent,
@@ -993,7 +1016,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			
 			if (responseType == (int) ResponseType.Yes) {
 				try {
-					PersonStore.RemoveGroup (group.Id);
+					PersonManager.RemoveGroup (group.Id);
 				} catch (Exception e) {
 					Logger.Warn ("Error removing the group: {0}\n{1}\n{2}",
 							group.DisplayName,
@@ -1016,13 +1039,10 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 
 	public delegate void GroupButtonClickedHandler (GroupButton sender, PersonGroup group); 
 
-	public class GroupButton : HBox
+	public class GroupButton : Button
 	{
 		private PersonGroup group;
 		private Label label;
-		private Button button;
-		private Button deleteButton;
-		private Image deleteImage;
 		
 		public GroupButton (PersonGroup personGroup)
 		{
@@ -1037,22 +1057,8 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			label.UseMarkup = true;
 			label.Show ();
 			hbox.PackStart (label, false, false, 4);
-			button = new Button (hbox);
-			button.Relief = ReliefStyle.None;
-			button.Show ();
-			button.Clicked += OnButtonClicked;
-			PackStart (button, true, true, 0);
-			
-			deleteImage = new Image (Stock.Delete, IconSize.Menu);
-			deleteImage.NoShowAll = true;
-			deleteButton = new Button (deleteImage);
-			deleteButton.Relief = ReliefStyle.None;
-			deleteButton.Show ();
-			deleteButton.Clicked += OnDeleteButtonClicked;
-			deleteButton.Entered += OnDeleteButtonMouseEnter;
-			deleteButton.Left += OnDeleteButtonMouseLeft;
-			
-			PackStart (deleteButton, false, false, 0);
+			this.Relief = ReliefStyle.None;
+			Add (hbox);
 		}
 		
 		public new void Show ()
@@ -1061,7 +1067,7 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 		}
 		
 		public event GroupButtonClickedHandler Clicked;
-		public event GroupButtonClickedHandler DeleteClicked;
+		public event GroupButtonClickedHandler RightClicked;
 		
 		public PersonGroup PersonGroup
 		{
@@ -1076,28 +1082,20 @@ Logger.Debug ("GroupWindow.BuildGroupButtonsView adding {0} groups",
 			}
 		}
 		
-		private void OnButtonClicked (object sender, EventArgs args)
+		protected override bool OnButtonPressEvent (Gdk.EventButton evnt)
 		{
-			if (Clicked != null)
-				Clicked (this, group);
-		}
-		
-		private void OnDeleteButtonClicked (object sender, EventArgs args)
-		{
-			if (DeleteClicked != null)
-				DeleteClicked (this, group);
-		}
-		
-		private void OnDeleteButtonMouseEnter (object sender, EventArgs args)
-		{
-			Logger.Debug ("OnDeleteButtonMouseEnter");
-			deleteImage.Show ();
-		}
-		
-		private void OnDeleteButtonMouseLeft (object sender, EventArgs args)
-		{
-			Logger.Debug ("OnDeleteButtonMouseLeft");
-			deleteImage.Hide ();
+			switch (evnt.Button) {
+			case 1: // left-click
+				if (Clicked != null)
+					Clicked (this, group);
+				break;
+			case 3: // right-click
+				if (RightClicked != null)
+					RightClicked (this, group);
+				break;
+			}
+			
+			return true;
 		}
 	}
 }
