@@ -41,7 +41,6 @@ namespace Banter
 	public class Person
 	{
 		#region Private Types
-		private bool isSelf;
 		private string photoFile = String.Empty;
 		private Evolution.Contact edsContact;
 		private string cachePath;
@@ -62,10 +61,7 @@ namespace Banter
 		/// </summary>
 		public Presence Presence
 		{
-			get
-			{
-				return presence;
-			}
+			get { return presence; }
 		}
 
 
@@ -74,10 +70,7 @@ namespace Banter
 		/// </summary>
 		public string PresenceMessage
 		{
-			get 
-			{			
-				return presence.Message;
-			}
+			get { return presence.Message; }
 		}		
 
 		
@@ -149,12 +142,15 @@ namespace Banter
 		/// <summary>
 		/// Indicates self awareness
 		/// </summary>
-		public bool IsSelf
+		public bool IsMe
 		{
-			get{ return isSelf;}
-			set
+			get
 			{
-				isSelf = value;
+				foreach(ProviderUser user in providerUsers) {
+					if(user.IsMe)
+						return true;
+				}
+				return false;
 			}
 		}
 
@@ -193,30 +189,16 @@ namespace Banter
 		/// </summary>
 		internal Person(Evolution.Contact edsContact)
 		{
-			this.isSelf = false;
 			this.edsContact = edsContact;
 			Init();
 		}
 
 		
-		/// <summary>
-		/// Constructs a ME person from an Evolution contact
-		/// </summary>
-		internal Person(Evolution.Contact edsContact, bool self)
-		{
-			this.isSelf = false;
-			this.edsContact = edsContact;
-			this.isSelf = self;			
-			Init();
-		}
-
-		
 		/// <summary>
 		/// Constructs a person with a displayName
 		/// </summary>
 		public Person(string displayName)
 		{
-			this.isSelf = false;
 			this.edsContact = new Contact();
 			edsContact.FileAs = displayName;
 			Init();
@@ -308,7 +290,7 @@ namespace Banter
 		/// AvatarTokenUpdated handler
 		/// AvatarReceived
 		/// </summary>
-		private void ProviderUserAvatarReceived (ProviderUser user, string token, byte[] avatarData)
+		private void ProviderUserAvatarReceived (ProviderUser user, string token, string mimeType, byte[] avatarData)
 		{
 			// FIXME: This needs to determine if the AvatarUpdated needs to be called depending
 			// on the avatar stored in EDS etc.
@@ -413,6 +395,21 @@ namespace Banter
 			UpdatePresence();
 		}
 		
+		/// <summary>
+		/// Sets the status for the person if the person IsMe
+		/// </summary>
+		public void SetStatus(Presence presence)
+		{
+			if(!this.IsMe)
+				return;
+			
+			if(providerUsers.Count > 0) {
+				foreach(ProviderUser user in providerUsers) {
+					user.SetStatus(presence);
+				}
+			}
+		}
+		
 		#endregion
 		
 	}	
